# Test footnotes

# Header 1

This file tests that footnotes work as intended [ 1 ]

## Header 2

The list of footnotes should be computed while the parser works on the text, so I expect the command `footnotes` to contain all of them in any part of the text [ 2 ]

1

Which means that links work and that I can add the command `footnotes` anywhere in the text.

2

This is my hope, at least.

3

Which, as I said, should appear both in the list above and in the one below.

### Header 3

This is here just to add another footnote [ 3 ] .

1

Which means that links work and that I can add the command `footnotes` anywhere in the text.

2

This is my hope, at least.

3

Which, as I said, should appear both in the list above and in the one below.